@@ -46,7 +46,7 @@ static char *buffrom;
 static char *bufto;
 static long psize;
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd);
 
 void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd)
@@ -94,8 +94,8 @@ void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *
 		write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 		unlink(cpinfo->to);
 		cpinfo->write = false;
-		// falseで初期化しているので要らないはず
-		//cpinfo->hash_check = false;
+		/* falseで初期化しているので要らないはず */
+		/* cpinfo->hash_check = false; */
 	}
 	else
 	{
@@ -224,6 +224,7 @@ END:
 			puts("compare success");
 			printf("from : %s\n", cpinfo->from);
 			printf("to   : %s\n", cpinfo->to);
+			fflush(stdout);
 		}
 	}
 }
