@@ -42,7 +42,7 @@
 	}\
 }
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 SData * get_file_list(const OPArg *oparg, const VList *drive_list);
 static VList * dir_traverse(VList *file_list, const CPInfo *cpinfo, CPDD *cpdd);
 static inline CPInfo * cpinfo_malloc(void) __attribute__((always_inline));
@@ -99,7 +99,7 @@ SData * get_file_list(const OPArg *oparg, const VList *drive_list)
 
 	memcpy(tmpto, oparg->argv[loopto], lento + 1);
 
-	// 三項演算子
+	/* 三項演算子 */
 	((loopto - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
 	for(; loop < loopto; loop++)
@@ -110,7 +110,7 @@ SData * get_file_list(const OPArg *oparg, const VList *drive_list)
 		delete_last_slash(lenfrom, tmpfrom);
 		delete_last_slash(lento, tmpto);
 
-		// strcmpは等しければ0を返す
+		/* strcmpは等しければ0を返す */
 		if((strcmp(tmpfrom, ".") == 0) || (strcmp(tmpfrom, "..") == 0))
 		{
 			continue;
@@ -283,6 +283,21 @@ SData * get_file_list(const OPArg *oparg, const VList *drive_list)
 *******************************************************************************/
 #include <dirent.h>
 
+#define TYPE_IS_LINK \
+count_link_plus(cpinfo, cpdd);\
+file_list = append_list(file_list, (void *)cpinfo);
+
+#define TYPE_IS_FILE \
+count_file_plus(cpinfo, cpdd);\
+do_stat(cpinfo, cpdd);\
+file_list = append_list(file_list, (void *)cpinfo);
+
+#define TYPE_IS_DIR \
+count_dire_plus(cpinfo, cpdd);\
+file_list = append_list(file_list, (void *)cpinfo);\
+/* 再帰 */ \
+file_list = dir_traverse(file_list, cpinfo, cpdd);
+
 static VList * dir_traverse(VList *file_list, const CPInfo *cpinfo_tmp, CPDD *cpdd)
 {
 	DIR *dp = NULL;
@@ -296,7 +311,7 @@ static VList * dir_traverse(VList *file_list, const CPInfo *cpinfo_tmp, CPDD *cp
 		while((entry = readdir(dp)) != NULL)
 		{
 			d_name = entry->d_name;
-			// strcmpは等しければ0を返す（0は偽）
+			/* strcmpは等しければ0を返す（0は偽） */
 			if(strcmp(d_name, ".") && strcmp(d_name, ".."))
 			{
 				int fdir = strlen(from_dir);
@@ -305,7 +320,7 @@ static VList * dir_traverse(VList *file_list, const CPInfo *cpinfo_tmp, CPDD *cp
 
 				CPInfo *cpinfo = cpinfo_malloc();
 
-				// +2は、 \0 と / の分
+				/* +2は、 \0 と / の分 */
 				cpinfo->from = xmalloc(fdir + d_len + 2);
 				cpinfo->to = xmalloc(tdir + d_len + 2);
 				cpinfo->tofs = cpinfo_tmp->tofs;
@@ -320,29 +335,34 @@ static VList * dir_traverse(VList *file_list, const CPInfo *cpinfo_tmp, CPDD *cp
 				switch(entry->d_type)
 				{
 				case DT_LNK:
-					count_link_plus(cpinfo, cpdd);
-
-					file_list = append_list(file_list, (void *)cpinfo);
+					TYPE_IS_LINK
 					break;
 
 				case DT_REG:
-					count_file_plus(cpinfo, cpdd);
-					do_stat(cpinfo, cpdd);
-
-					file_list = append_list(file_list, (void *)cpinfo);
+					TYPE_IS_FILE
 					break;
 
 				case DT_DIR:
-					count_dire_plus(cpinfo, cpdd);
-
-					file_list = append_list(file_list, (void *)cpinfo);
-
-					// 再帰
-					file_list = dir_traverse(file_list, cpinfo, cpdd);
+					TYPE_IS_DIR
 					break;
 
 				default:
-					fprintf(stderr, "このファイル (%s) をスキップします\n", cpinfo->from);
+					if(g_file_test(cpinfo->from, G_FILE_TEST_IS_SYMLINK) == TRUE)
+					{
+						TYPE_IS_LINK
+					}
+					else if(g_file_test(cpinfo->from, G_FILE_TEST_IS_REGULAR) == TRUE)
+					{
+						TYPE_IS_FILE
+					}
+					else if(g_file_test(cpinfo->from, G_FILE_TEST_IS_DIR) == TRUE)
+					{
+						TYPE_IS_DIR
+					}
+					else
+					{
+						fprintf(stderr, "このファイル (%s) をスキップします\n", cpinfo->from);
+					}
 					break;
 				}
 			}
@@ -493,7 +513,7 @@ BASENAME_END:
 	if(flag == true)
 	{
 		int nlen = strlen(fname);
-		// +1 はヌル文字（\0）の分
+		/* +1 はヌル文字（\0）の分 */
 		return_name = xmalloc(tlen + nlen + 1);
 		memcpy(return_name, to, tlen + 1);
 		strcat(return_name, fname);
