@@ -1,8 +1,8 @@
 #include <stdio.h>
 
-static char version[] = "0.10.8 beta";
+static char version[] = "0.11.3 beta";
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void help(void);
 
 /*******************************************************************************
@@ -30,18 +30,17 @@ void help()
 	puts(" -0         ベリファイ・コンペアを行わない。");
 	puts("            (-1、-5、-c、-rオプションを無効にする。)");
 	puts("");
-	puts(" -b NUMBER  バッファの量を指定する（MB単位）。");
+	puts(" -b NUMBER  バッファの量を指定する（MB単位、デフォルト値は32）。");
 	puts("            (例 : snowcp -b 64 source dest)");
 	puts("");
+/*
 	puts(" -c MODE    memcmpで比較する。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
 	puts("            一致しなかった場合はdestを削除する。");
 	puts("            (例 : snowcp -c 1 source dest)");
-//	puts("");
-//	puts(" -d         ダイレクトI/Oを使用する。");
-//	puts("            (このオプションは非推奨です。)");
 	puts("");
+*/
 	puts(" -h         ヘルプを表示する。");
 	puts("            (例 : snowcp -h)");
 	puts("");
