@@ -50,7 +50,7 @@ enum I_OverWrite_Type
 	}\
 }
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void process_file_list(const OPArg *oparg, const VList *file_list, SDir *sdir, CPDD *cpdd);
 static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
 static inline void clean(const char stdin_buf[], const int INPUT_LEN) __attribute__((always_inline));
@@ -67,12 +67,12 @@ void process_file_list(const OPArg *oparg, const VList *file_list, SDir *sdir, C
 	{
 		CPInfo *data;
 		struct DirList *next;
-		// tailは先頭の要素のみ使用、他はNULL
+		/* tailは先頭の要素のみ使用、他はNULL */
 		struct DirList *tail;
 	};
 	struct DirList *dir_list = NULL;
 
-	// 変更される可能性があるオプションはローカル変数に入れておく
+	/* 変更される可能性があるオプションはローカル変数に入れておく */
 	OPFlag I = oparg->I;
 	OPFlag WMODE = oparg->WRITE_MODE;
 
@@ -89,16 +89,16 @@ void process_file_list(const OPArg *oparg, const VList *file_list, SDir *sdir, C
 
 		if(cpinfo->from_type != SYMBOLICLINK)
 		{
-			// シンボリックリンクはFALSEになるらしい
+			/* シンボリックリンクはFALSEになるらしい */
 			fcheck = g_file_test(cpinfo->to, G_FILE_TEST_EXISTS);
 		}
 
 		if(cpinfo->from_type != DIRECTORY)
 		{
-			// REGULAR or SYMBOLICLINK
+			/* REGULAR or SYMBOLICLINK */
 
-			// TRUE・FALSE　→　glib
-			// true・false　→　stdbool
+			/* TRUE・FALSE　→　glib */
+			/* true・false　→　stdbool */
 			if(fcheck == FALSE)
 			{
 				if(cpinfo->from_type == REGULAR)
@@ -116,13 +116,16 @@ void process_file_list(const OPArg *oparg, const VList *file_list, SDir *sdir, C
 
 				if(I == INTERACTIVE)
 				{
-					// -i（上書き確認）モード
-
-					// ここの処理はgoto使わずに関数にまとめた方が分かりやすいかもしれない
+					/*
+					 * -i（上書き確認）モード
+					 * ここの処理はgoto使わずに関数にまとめた方が分かりやすいかもしれない
+					*/
 INPUT:
-					// gotoのラベルの直後で変数の宣言をすると、
-					// a label can only be part of a statement and a declaration is not a statement
-					// というエラーが出る。
+					/*
+					 * gotoのラベルの直後で変数の宣言をすると、
+					 * a label can only be part of a statement and a declaration is not a statement
+					 * というエラーが出る。
+					 */
 
 					switch(iowt)
 					{
@@ -154,39 +157,39 @@ INPUT:
 
 						switch(stdin_buf[0])
 						{
-						case 'y':	// 上書き
+						case 'y':	/* 上書き */
 							FILE_WRITE_OR_CREATE_LINK_OVERWRITE
 							break;
 
-						case 'a':	// 全て上書き
+						case 'a':	/* 全て上書き */
 							FILE_WRITE_OR_CREATE_LINK_OVERWRITE
-							I = NOT;	// 上書き確認モード無効
-							//WMODE = OVERWRITE;
-							// ↑上書き確認モードでは最初からOVERWRITEになっている
+							I = NOT;	/* 上書き確認モード無効 */
+							/* WMODE = OVERWRITE; */
+							/* ↑上書き確認モードでは最初からOVERWRITEになっている */
 							break;
 
-						case 'd':	// このフォルダでのみ上書き
+						case 'd':	/* このフォルダでのみ上書き */
 							FILE_WRITE_OR_CREATE_LINK_OVERWRITE
 							iowt = THIS_DIR_YES;
 							THIS_DIR_FREE
 							this_dir = g_path_get_dirname(cpinfo->from);
 							break;
 
-						case 'n':	// 上書きしない
+						case 'n':	/* 上書きしない */
 							DO_NOT_OVERWRITE_FLAG
 							break;
 
-						case 'o':	// このフォルダでは上書きしない
+						case 'o':	/* このフォルダでは上書きしない */
 							DO_NOT_OVERWRITE_FLAG
 							iowt = THIS_DIR_NO;
 							THIS_DIR_FREE
 							this_dir = g_path_get_dirname(cpinfo->from);
 							break;
 
-						case 'z':	// 全て上書きしない
+						case 'z':	/* 全て上書きしない */
 							DO_NOT_OVERWRITE_FLAG
-							I = NOT;	// 上書き確認モード無効
-							WMODE = NO_OVERWRITE;	// 非上書きモード
+							I = NOT;	/* 上書き確認モード無効 */
+							WMODE = NO_OVERWRITE;	/* 非上書きモード */
 							break;
 						}
 						break;
@@ -198,7 +201,7 @@ INPUT:
 						}
 						else
 						{
-							// 再び上書き確認モードに
+							/* 再び上書き確認モードに */
 							iowt = INFO;
 							goto INPUT;
 						}
@@ -211,7 +214,7 @@ INPUT:
 						}
 						else
 						{
-							// 再び上書き確認モードに
+							/* 再び上書き確認モードに */
 							iowt = INFO;
 							goto INPUT;
 						}
@@ -233,12 +236,12 @@ INPUT:
 		}
 		else
 		{
-			// cpinfo->from_type == DIRECTORY
+			/* cpinfo->from_type == DIRECTORY */
 
 			errno = 0;
 			if(g_file_test(cpinfo->to, G_FILE_TEST_EXISTS) == TRUE)
 			{
-				// フォルダの作成は行わない
+				/* フォルダの作成は行わない */
 				DO_NOT_OVERWRITE_FLAG
 			}
 			else if(mkdir(cpinfo->to, 0755) == -1)
@@ -259,9 +262,10 @@ INPUT:
 				if(oparg->V == VERBOS)
 				{
 					printf("%s -> %s\n", cpinfo->from, cpinfo->to);
+					fflush(stdout);
 				}
 
-				// alloca使いたかったんで関数にしなかった
+				/* alloca使いたかったんで関数にしなかった */
 				if(dir_list != NULL)
 				{
 					struct DirList *now = alloca(sizeof(struct DirList));
@@ -276,7 +280,7 @@ INPUT:
 				}
 				else
 				{
-					// リストに最初の要素を追加する
+					/* リストに最初の要素を追加する */
 					dir_list = alloca(sizeof(struct DirList));
 					dir_list->data = cpinfo;
 					dir_list->next = NULL;
@@ -334,11 +338,15 @@ static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, CPDD *cpdd)
 		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->to);
 	}
 
+/*
 	if(chown(cpinfo->to, stat_buf.st_uid, stat_buf.st_gid) == -1)
 	{
 		print_error("chown", __FILE__, __LINE__, cpdd);
 		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->to);
 	}
+*/
+
+	chown(cpinfo->to, stat_buf.st_uid, stat_buf.st_gid);
 
 	times.actime  = stat_buf.st_atime;
 	times.modtime = stat_buf.st_mtime;
@@ -355,7 +363,7 @@ static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, CPDD *cpdd)
 *******************************************************************************/
 static inline void clean(const char stdin_buf[], const int INPUT_LEN)
 {
-	// バッファチェック
+	/* バッファチェック */
 	_Bool flag = false;
 	for(int i = 0; i < INPUT_LEN; i++)
 	{
@@ -365,7 +373,7 @@ static inline void clean(const char stdin_buf[], const int INPUT_LEN)
 			break;
 		}
 	}
-	// 入力バッファの掃除
+	/* 入力バッファの掃除 */
 	if(flag == false)
 	{
 		while(getchar() != '\n');
