@@ -6,7 +6,6 @@
 
 #include "ch_time_and_mod.h" // inline
 #include "compare_hash.h"
-#include "compare_memcmp.h"
 #include "print_error.h" // inline
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
@@ -31,14 +30,14 @@
 #define TO_OPEN \
 {\
 	errno = 0;\
-	if((ito = open(cpinfo->to, O_CREAT | O_NOATIME | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
+	if((ito = open(cpinfo->to, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW | O_NOATIME, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
 	{\
 		switch(errno)\
 		{\
 		case EPERM:\
 			errno = 0;\
 \
-			if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
+			if((ito = open(cpinfo->to, O_CREAT | O_WRONLY | O_TRUNC | O_NOFOLLOW, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
 			{\
 				print_error("open", __FILE__, __LINE__, cpdd);\
 			}\
@@ -115,13 +114,12 @@ static _Bool from_open;
 static _Bool from_stat;
 static _Bool to_open;
 
-// ※注意。グローバル変数。
+/* ※注意。グローバル変数。 */
 char *write_now;
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
-static void * read_thread(void *unknown);
-static void * write_thread(void *unknown);
+static void * read_thread_func(void *unknown);
 static void * do_md5_append(void *tmp);
 
 /*******************************************************************************
@@ -179,7 +177,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	cpinfo->from_size = 0;
 	cpinfo->to_size = 0;
 
-	// signalハンドラ用
+	/* signalハンドラ用 */
 	write_now = cpinfo->to;
 
 	errno = 0;
@@ -307,17 +305,14 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	*/
 	if((from_size_local > 0) && (to_open == true) && (fallocate_support == true))
 	{
-		static int itmp = -1;
-
-		// Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。
-		// linux/falloc.h のincludeが必要。
-		if((itmp = fallocate(ito, FALLOC_FL_KEEP_SIZE, 0, from_size_local)) != 0)
+		/* Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。linux/falloc.h のincludeが必要。 */
+		if(fallocate(ito, FALLOC_FL_KEEP_SIZE, 0, from_size_local) == -1)
 		{
-			errno = itmp;
 			print_error("fallocate", __FILE__, __LINE__, cpdd);
 		}
-
 /*
+		static int itmp = -1;
+
 		if((itmp = posix_fallocate(ito, 0, from_size_local)) != 0)
 		{
 			errno = itmp;
@@ -326,13 +321,13 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 */
 	}
 
-	// コピー開始
+	/* コピー開始 */
 	if((from_size_local > 0) && (to_open == true))
 	{
 		static md5_state_t state;
 		static md5_byte_t digest[16];
 		static struct verify_data thread_argument;
-		static pthread_t pverify;
+		static pthread_t t_verify;
 
 		if(verify == true)
 		{
@@ -342,9 +337,10 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		if(oparg->V == VERBOS)
 		{
 			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
+			fflush(stdout);
 		}
 
-		// 1048576 == 1024 * 1024 == 1MB
+		/* 1048576 == 1024 * 1024 == 1MB */
 		if(1048576 > from_size_local)
 		{
 			errno = 0;
@@ -359,7 +355,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				total_read_local = from_size_local;
 
 				errno = 0;
-				if(madvise(buf[0], from_size_local, MADV_SEQUENTIAL) != 0)
+				if(madvise(buf[0], from_size_local, MADV_SEQUENTIAL) == -1)
 				{
 					print_error("madvise", __FILE__, __LINE__, cpdd);
 				}
@@ -370,7 +366,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					thread_argument.buffer = buf[0];
 					thread_argument.len = from_size_local;
 
-					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+					pthread_create(&t_verify, NULL, do_md5_append, (void *)&thread_argument);
 				}
 
 				char *tmp = buf[0];
@@ -390,7 +386,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 
 				if(verify == true)
 				{
-					pthread_join(pverify, NULL);
+					pthread_join(t_verify, NULL);
 
 					MD5_FINISH
 				}
@@ -424,8 +420,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 						buffer_size_thread = low;
 						break;
 					}
-
-					if(b_size_list->prev == NULL)
+					else if(b_size_list->prev == NULL)
 					{
 						buffer_size_thread = buffer_size_half;
 						break;
@@ -439,18 +434,21 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 			}
 
 			rbuf_num = 0;
+			wbuf_num = 1;
 
-			pthread_t t1;
-			pthread_t t2;
-			pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
-			pthread_join(t1, NULL);
+			pthread_t t_read;
+			pthread_create(&t_read, NULL, read_thread_func, (void *)&rbuf_num);
+			pthread_join(t_read, NULL);
+
+			int num_change;
 
 			for(;;)
 			{
-				rbuf_num = 1;
-				wbuf_num = 0;
+				num_change = rbuf_num;
+				rbuf_num = wbuf_num;
+				wbuf_num = num_change;
 
-				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+				pthread_create(&t_read, NULL, read_thread_func, (void *)&rbuf_num);
 
 				if(verify == true)
 				{
@@ -458,37 +456,49 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					thread_argument.buffer = buf[wbuf_num];
 					thread_argument.len = next_write_size[wbuf_num];
 
-					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
-					pthread_join(pverify, NULL);
+					pthread_create(&t_verify, NULL, do_md5_append, (void *)&thread_argument);
 				}
 
-				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
-				pthread_join(t1, NULL);
-				pthread_join(t2, NULL);
-
-				if((from_size_local <= total_write_local) || (written_size[wbuf_num] <= 0))
+				if(next_write_size[wbuf_num] > 0)
 				{
-					break;
+					char *tmp = (char *)buf[wbuf_num];
+					const char * const endp = tmp + next_write_size[wbuf_num];
+
+					while(tmp < endp)
+					{
+						errno = 0;
+						if((written_size[wbuf_num] = write(ito, tmp, endp - tmp)) == -1)
+						{
+							print_error("write", __FILE__, __LINE__, cpdd);
+							total_write_error++;
+							break;
+						}
+
+						tmp += written_size[wbuf_num];
+						total_write_local += written_size[wbuf_num];
+					}
+				}
+				else
+				{
+					written_size[wbuf_num] = 0;
 				}
-
-				rbuf_num = 0;
-				wbuf_num = 1;
-
-				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
 
 				if(verify == true)
 				{
-					thread_argument.state = &state;
-					thread_argument.buffer = buf[wbuf_num];
-					thread_argument.len = next_write_size[wbuf_num];
-
-					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
-					pthread_join(pverify, NULL);
+					pthread_join(t_verify, NULL);
 				}
 
-				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
-				pthread_join(t1, NULL);
-				pthread_join(t2, NULL);
+				if(next_write_size[wbuf_num] > 0)
+				{
+					errno = 0;
+					if(munmap(buf[wbuf_num], next_write_size[wbuf_num]) == -1)
+					{
+						print_error("munmap", __FILE__, __LINE__, cpdd);
+						total_write_error++;
+					}
+				}
+
+				pthread_join(t_read, NULL);
 
 				if((from_size_local <= total_write_local) || (written_size[wbuf_num] <= 0))
 				{
@@ -534,7 +544,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					total_read_local += read_size;
 
 					errno = 0;
-					if(madvise(buf[0], read_size, MADV_SEQUENTIAL) != 0)
+					if(madvise(buf[0], read_size, MADV_SEQUENTIAL) == -1)
 					{
 						print_error("madvise", __FILE__, __LINE__, cpdd);
 					}
@@ -545,7 +555,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 						thread_argument.buffer = buf[0];
 						thread_argument.len = read_size;
 
-						pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+						pthread_create(&t_verify, NULL, do_md5_append, (void *)&thread_argument);
 					}
 
 					char *tmp = buf[0];
@@ -572,7 +582,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 
 					if(verify == true)
 					{
-						pthread_join(pverify, NULL);
+						pthread_join(t_verify, NULL);
 					}
 
 					errno = 0;
@@ -594,28 +604,6 @@ LOOP_END:
 				MD5_FINISH
 			}
 		}
-
-		/*
-		 * 余計に書き込んだ部分を切り詰める。
-		 * または大きなファイルを小さなファイルで上書きした場合のリサイズ。
-		 * open時にO_TRUNCしてない場合、重要な処理。
-		 * ここを弄ってバージョン0.1.2でバグを出したので、うかつに弄らない。
-		*/
-		{
-			static struct stat to_stat_tmp;
-
-			if(fstat(ito, &to_stat_tmp) == -1)
-			{
-				print_error("fstat", __FILE__, __LINE__, cpdd);
-			}
-			else if(from_size_local < to_stat_tmp.st_size)
-			{
-				if(ftruncate(ito, from_size_local) == -1)
-				{
-					print_error("ftruncate", __FILE__, __LINE__, cpdd);
-				}
-			}
-		}
 	}
 	else if((from_size_local == 0) && (to_open == true))
 	{
@@ -702,14 +690,14 @@ LOOP_END:
 		case FIVE:
 			HASH_CHECK
 			break;
-
+/*
 		case MEMCMP:
 			if((cpinfo->from_size > 0) && (cpinfo->to_size > 0))
 			{
 				compare_memcmp(oparg, cpinfo, sdir, cpdd);
 			}
 			break;
-
+*/
 		case V_FIVE:
 			if(cpinfo->verify_md5 == NULL)
 			{
@@ -744,6 +732,7 @@ LOOP_END:
 		if(oparg->V == VERBOS)
 		{
 			puts("");
+			fflush(stdout);
 		}
 	}
 }
@@ -751,10 +740,10 @@ LOOP_END:
 /*******************************************************************************
  * 読み取り関数。引数は使用しない。
 *******************************************************************************/
-static void * read_thread(void *unknown)
+static void * read_thread_func(void *unknown)
 {
 	int i = rbuf_num;
-	unknown++;	// コンパイル時のwarningを出さないようにするため
+	unknown++;	/* コンパイル時のwarningを出さないようにするため */
 
 	if(from_size_local <= total_read_local)
 	{
@@ -782,8 +771,8 @@ static void * read_thread(void *unknown)
 
 	if(buf[i] == MAP_FAILED)
 	{
-		// このcpddに意味はない。print_errorの引数用。
-		static CPDD cpdd;
+		/* このcpddに意味はない。print_errorの引数用。 */
+		CPDD cpdd;
 		cpdd.total_error = 0;
 		print_error("mmap", __FILE__, __LINE__, &cpdd);
 		total_read_error++;
@@ -793,12 +782,11 @@ static void * read_thread(void *unknown)
 	else
 	{
 		errno = 0;
-		// マルチスレッドの場合、
-		// MADV_SEQUENTIALよりもMADV_WILLNEEDの方が速い、ような気がする。
-		if(madvise(buf[i], read_size, MADV_WILLNEED) != 0)
+		/* マルチスレッドの場合、MADV_SEQUENTIALよりもMADV_WILLNEEDの方が速い、ような気がする。 */
+		if(madvise(buf[i], read_size, MADV_WILLNEED) == -1)
 		{
-			// このcpddに意味はない。print_errorの引数用。
-			static CPDD cpdd;
+			/* このcpddに意味はない。print_errorの引数用。 */
+			CPDD cpdd;
 			cpdd.total_error = 0;
 			print_error("madvise", __FILE__, __LINE__, &cpdd);
 			total_read_error++;
@@ -811,53 +799,6 @@ static void * read_thread(void *unknown)
 	return NULL;
 }
 
-/*******************************************************************************
- * 書き込み関数。引数は使用しない。
-*******************************************************************************/
-static void * write_thread(void *unknown)
-{
-	int i = wbuf_num;
-	unknown++;	// コンパイル時のwarningを出さないようにするため
-
-	if(next_write_size[i] > 0)
-	{
-		char *tmp = (char *)buf[i];
-		const char * const endp = tmp + next_write_size[i];
-
-		while(tmp < endp)
-		{
-			errno = 0;
-			if((written_size[i] = write(ito, tmp, endp - tmp)) == -1)
-			{
-				// このcpddに意味はない。print_errorの引数用。
-				static CPDD cpdd;
-				cpdd.total_error = 0;
-				print_error("write", __FILE__, __LINE__, &cpdd);
-				total_write_error++;
-				break;
-			}
-			tmp += written_size[i];
-			total_write_local += written_size[i];
-		}
-
-		errno = 0;
-		if(munmap(buf[i], next_write_size[i]) == -1)
-		{
-			// このcpddに意味はない。print_errorの引数用。
-			static CPDD cpdd;
-			cpdd.total_error = 0;
-			print_error("munmap", __FILE__, __LINE__, &cpdd);
-			total_write_error++;
-		}
-	}
-	else
-	{
-		written_size[i] = 0;
-	}
-
-	return NULL;
-}
-
 /*******************************************************************************
  * ベリファイ用
 *******************************************************************************/
