@@ -5,4 +5,4 @@
 
 extern char *write_now;
 
-extern _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
+extern void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
