@@ -1,6 +1,5 @@
 #include "analyze_argument.h"
 #include "compare_hash.h"
-#include "compare_memcmp.h"
 #include "get_drive_list.h"
 #include "get_file_list.h"
 #include "get_settings_dir.h"
@@ -20,7 +19,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd) __attribute__((always_inline));
 static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
 
@@ -40,19 +39,19 @@ int main(int argc, char **argv)
 	{
 		char *tmp = argv[1];
 
-		// -oの場合、オプションを設定、保存し、終了する。
+		/* -oの場合、オプションを設定、保存し、終了する。 */
 		if((tmp[0] == '-') && (tmp[1] == 'o'))
 		{
 			write_conf(sdir);
 			return EXIT_SUCCESS;
 		}
-		// -hの場合はヘルプを表示する
+		/* -hの場合はヘルプを表示する */
 		else if((tmp[0] == '-') && (tmp[1] == 'h'))
 		{
 			help();
 			return EXIT_SUCCESS;
 		}
-		// --helpの場合もヘルプを表示する
+		/* --helpの場合もヘルプを表示する */
 		else if((tmp[0] == '-') && (tmp[1] == '-') && (tmp[2] == 'h') && (tmp[3] == 'e') && (tmp[4] == 'l') && (tmp[5] == 'p'))
 		{
 			help();
@@ -111,9 +110,9 @@ int main(int argc, char **argv)
 	printf("File   : %lld / %lld\n", cpdd->mk_file_count, cpdd->file_count);
 	printf("Link   : %lld / %lld\n", cpdd->mk_link_count, cpdd->link_count);
 	printf("Dir    : %lld / %lld\n", cpdd->mk_dir_count, cpdd->dir_count);
-	printf("Source : %lld MB (%lld Byte)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source);
-	printf("Read   : %lld MB (%lld Byte)\n", cpdd->total_read / (1024 * 1024), cpdd->total_read);
-	printf("Write  : %lld MB (%lld Byte)\n", cpdd->total_write / (1024 * 1024), cpdd->total_write);
+	printf("Source : %lld MB (%lld Bytes)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source);
+	printf("Read   : %lld MB (%lld Bytes)\n", cpdd->total_read / (1024 * 1024), cpdd->total_read);
+	printf("Write  : %lld MB (%lld Bytes)\n", cpdd->total_write / (1024 * 1024), cpdd->total_write);
 
 	if(cpdd->total_error > 0)
 	{
@@ -125,9 +124,7 @@ int main(int argc, char **argv)
 	 * sdir->current_fd
 	*/
 
-	/*
-	 * 基本的に、mallocしたのはfreeしてない。
-	*/
+	/* 基本的に、mallocしたのはfreeしてない。 */
 
 	puts("");
 
@@ -174,14 +171,14 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 			case FIVE:
 				HASH_CHECK
 				break;
-
+/*
 			case MEMCMP:
 				if((cpinfo->from_size > 0) && (cpinfo->to_size > 0))
 				{
 					compare_memcmp(oparg, cpinfo, sdir, cpdd);
 				}
 				break;
-
+*/
 			case V_FIVE:
 				if(cpinfo->verify_md5 == NULL)
 				{
