@@ -34,7 +34,7 @@ static _Bool lseek_err;
 static _Bool read_err;
 static _Bool read_finish;
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd);
 static void * read_func(void *dummy);
 static void * append_func(void *dummy);
@@ -87,9 +87,8 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 		open_flag = true;
 	}
 
-	switch(open_flag)
+	if(open_flag == true)
 	{
-	case true:
 		if((buf[0] == NULL) &&(buf[1] == NULL))
 		{
 			if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
@@ -166,6 +165,7 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 					puts("compare success");
 					printf("%s : %s\n", cpinfo->verify_md5, cpinfo->from);
 					printf("%s : %s\n", hex_output, cpinfo->to);
+					fflush(stdout);
 				}
 
 				if(oparg->L == LOG)
@@ -191,15 +191,14 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 			cpinfo->write = false;
 			break;
 		}
-		break;
-
-	case false:
+	}
+	else
+	{
 		fprintf(stderr, "ベリファイに失敗しました\n");
 		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->to);
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
 		cpinfo->write = false;
-		break;
 	}
 
 	if(open_flag == true)
@@ -209,9 +208,10 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 			print_error("close", __FILE__, __LINE__, cpdd);
 		}
 	}
-
-//	free(buf[0]);
-//	free(buf[1]);
+/*
+	free(buf[0]);
+	free(buf[1]);
+*/
 }
 
 /*******************************************************************************
@@ -221,7 +221,7 @@ static void * read_func(void *dummy)
 	static int i;
 	static int try_count;
 
-	dummy++;// コンパイル時のwarningを出さないようにするため
+	dummy++;	/* コンパイル時のwarningを出さないようにするため */
 
 	i = r_number;
 	try_count = 0;
@@ -287,7 +287,7 @@ static void * append_func(void *dummy)
 
 	md5_append(&state, buf[i], read_size[i]);
 
-	dummy++;// コンパイル時のwarningを出さないようにするため
+	dummy++;	/* コンパイル時のwarningを出さないようにするため */
 
 	return NULL;
 }
